#!/usr/bin/env python

import os
import sys

#h=0.1,stencils=(3,3),k=10,10,10
# symbol : (a[A], B[GPa], Ecoh[Ev], struc)
#           LAPW  LAPW    ? GPAW-FD fra artikel

class Ref:
    def __init__(self, symbol, a, B, e, structure, kpts, h):
        self.symbol = symbol
        self.a = a
        self.B = B
        self.e = e
        self.structure = structure
        self.kpts = kpts
        self.h = h

refs = {
    'C':   Ref('C', 3.575, 431.0, 7.73, 'diamond', (4, 6, 6), .12),
    'Si':  Ref('Si', 5.459,  87.8, 4.56, 'diamond', (4, 6, 6), .18),
    'Li':   Ref('Li', 3.438,  13.7, 1.63, 'bcc', (12, 12, 12), .12),
    'Na':   Ref('Na', 4.200,   7.6, 1.09, 'bcc', (10, 10, 10), .17),
    'Fe':   Ref('Fe', 2.860, 198.0, 0.00, 'bcc', (12, 12, 12), .10),
    'Al':   Ref('Al', 4.039,  76.5, 3.42, 'fcc', (10, 16, 16), .16),
    'Cu':   Ref('Cu', 3.628, 143.9, 99.99, 'fcc', (8, 12, 12), .10),
    'Pt':   Ref('Pt', 3.999, 234.0, 0.00, 'fcc', (6, 8, 8), .12),
    'FLi':  Ref('FLi', 4.064,  71.7, 4.13, 'rocksalt', (4, 4, 4), .08),
    'MgO':  Ref('MgO', 4.259, 147.8, 5.06, 'rocksalt', (2, 2, 2), .1),
    'NaCl': Ref('NaCl', 5.714,  23.7, 3.13, 'rocksalt', (2, 2, 2), .10),
    'SiC':  Ref('SiC', 4.381, 211.8, 6.42, 'zincblende', (4, 4, 4), .12),
    'PAl':  Ref('PAl', 5.513,  82.6, 4.06, 'zincblende', (4, 4, 4), .17)}

refitems = refs.items()
refitems.sort()

#h = 0.12
k = (8, 10, 10)
mode = 'lcao'
basis = 'dzp'

def get_identifier(mode, basis):
    identifier = '.'.join([mode, basis])
    return identifier

def qsubcmd(sym, identifier):
    identifier = '-'.join([sym, identifier])
    args = ['gpaw-qsub',
            '-l nodes=1:ppn=4:opteron285',
            #'-l nodes=1:ppn=8:xeon5570',
            '-l walltime=10:0:0',
            #'-q long',
            '-N %s' % identifier,
            '-e %s.niflheim.err' % identifier,
            '-m ae',
            '-o %s.niflheim.out' % identifier]
    qsub = ' '.join(args)
    return qsub

def gpawcmd(symbol, mode, basis, ref, identifier):
    args = ['gpawscript.py',
            '--identifier=%s' % identifier,
            '--grid-spacing %.3f' % ref.h,
            '--finite-difference-stencils 3,3',
            '-k %s' % ','.join(map(str, ref.kpts)),
            #'-k %d,%d,%d' % k,
            '--xc-functional PBE',
            '--orthorhombic',
            '--output %s-%s.log' % (symbol, identifier),
            '--mode %s' % mode,
            '--basis %s' % basis,
            '--crystal-structure %s' % ref.structure,
            '--atomization-energy',
            '--lattice-constant %.4f' % ref.a,
            '--optimize',
            '--vacuum 6.0',
            '--gpaw=log2ng=15',
            symbol]
    if symbol == 'Fe':
        args.append('-M 2.3')
    args.extend(sys.argv[1:])
    job = ' '.join(args)
    return job

def mkjob(symbol, mode, basis, ref):
    identifier = get_identifier(mode, basis)
    job = gpawcmd(symbol, mode, basis, ref, identifier)
    qsub = qsubcmd(symbol, identifier)
    cmd = ' '.join([qsub, job])
    trajname1 = '%s-%s.traj' % (symbol, identifier)
    trajname2 = '%s-%s-atom.traj' % (symbol, identifier)
    #if os.path.exists(trajname1) and os.path.exists(trajname2):
    #    return
    print cmd

basis_sets = {'fd' : ['sz'], 'lcao' : ['sz', 'dz', 'szp', 'dzp']}
for mode in ['fd', 'lcao']:
    for basis in basis_sets[mode]:
        for symbol, ref in refitems:
            mkjob(symbol, mode, basis, ref)
